Skip to contents

This function retrieves the complete project configuration (if existent) from an iDAI.field project via Field Desktop's configuration endpoint. The list will contain the complete configuration as used in the project, including custom fields, valuelists and translations.

Usage

get_configuration(connection)

Arguments

connection

A connection object as returned by connect_idaifield()

Value

A list of class idaifield_config containing the project configuration, with connection and projectname stored as attributes. Returns NA with a warning if the configuration could not be found or the connection failed.

See also

Examples

if (FALSE) { # \dontrun{
conn <- connect_idaifield(
  serverip = "localhost", pwd = "hallo", project = "rtest"
)
config <- get_configuration(connection = conn)
} # }