Query docs from an iDAI.field Database Based on an Index (uidlist)
Source:R/idf_query.R
idf_index_query.RdThis function can be used to gather docs from an iDAI.field / Field
Desktop Database according to the values of listed in an index as returned
by get_field_index() or make_index().
Arguments
- connection
A connection object as returned by
connect_idaifield()- field
character. The resource field that should be selected for (options are limited to the column names of the uidlist).
- value
character. The value to be selected for in the specified field.
- uidlist
A data.frame as returned by
get_field_index()(ormake_index()).
See also
Alternative functions:
idf_query(),idf_json_query()
Examples
if (FALSE) { # \dontrun{
conn <- connect_idaifield(pwd = "hallo", project = "rtest")
uidlist <- get_field_index(conn)
idf_index_query(conn,
field = "category",
value = "Brick",
uidlist = uidlist)
} # }